@@ -1,26 +1,27 @@
 import numpy as np  # type: ignore
-from typing import List, Optional
+from typing import List, Optional, Any
 
-from uniplot.options import Options
+from uniplot.multi_series import MultiSeries
 import uniplot.layer_assembly as layer_assembly
 import uniplot.plot_elements as elements
 from uniplot.getch import getch
+from uniplot.param_initializer import validate_and_transform_options
 
 
-def plot(ys: np.array, xs: Optional[np.array] = None, **kwargs) -> None:
-    """2D scatter dot plot on the terminal."""
-    ys = np.array(ys)
-    if xs is None:
-        xs = np.arange(1, len(ys) + 1, step=1, dtype=int)
-    else:
-        xs = np.array(xs)
+def plot(ys: Any, xs: Optional[Any] = None, **kwargs) -> None:
+    """
+    2D scatter dot plot on the terminal.
 
-    # Set bounds to show all points by default
-    kwargs["x_min"] = kwargs.get("x_min") or xs.min()
-    kwargs["x_max"] = kwargs.get("x_max") or (xs.max() + 0.01 * (xs.max() - xs.min()))
-    kwargs["y_min"] = kwargs.get("y_min") or ys.min()
-    kwargs["y_max"] = kwargs.get("y_max") or (ys.max() + 0.01 * (ys.max() - ys.min()))
-    options = Options(**kwargs)
+    Parameters:
+
+    - `ys` are the y coordinates of the points to plot. This parameter is mandatory and
+      can either be a list or a list of lists, or the equivalent NumPy array.
+    - `xs` are the x coordinates of the points to plot. This parameter is optional and
+      can either be a `None` or of the same shape as `ys`.
+    - Any additional keyword arguments are passed to the `uniplot.options.Options` class.
+    """
+    series = MultiSeries(xs=xs, ys=ys)
+    options = validate_and_transform_options(series=series, kwargs=kwargs)
 
     # Print title
     if options.title is not None:
@@ -44,12 +45,15 @@ def plot(ys: np.array, xs: Optional[np.array] = None, **kwargs) -> None:
 
         # Prefare graph surface
         pixel_character_matrix = layer_assembly.assemble_scatter_plot(
-            xs=xs, ys=ys, options=options
+            xs=series.xs, ys=series.ys, options=options
         )
 
         # Delete plot before we re-draw
         if loop_iteration > 0:
-            elements.erase_previous_lines(options.height + 4)
+            nr_lines_to_erase = options.height + 4
+            if options.legend_labels is not None:
+                nr_lines_to_erase += len(options.legend_labels)
+            elements.erase_previous_lines(nr_lines_to_erase)
 
         # Print plot (double resolution)
         print(f"┌{'─'*options.width}┐")
@@ -59,8 +63,13 @@ def plot(ys: np.array, xs: Optional[np.array] = None, **kwargs) -> None:
         print(f"└{'─'*options.width}┘")
         print(x_axis_labels)
 
+        # Print legend if labels were specified
+        # TODO Fix erase during interactive mode
+        if options.legend_labels is not None:
+            print(elements.legend(options.legend_labels, width=options.width))
+
         if options.interactive:
-            print("Move h/j/k/l, zoom u/n, or r to reset. Escape/q to quit")
+            print("Move h/j/k/l, zoom u/n, or r to reset. ESC/q to quit")
             key_pressed = getch().lower()
 
             # TODO Move all of the below to the `Options` class
@@ -101,11 +110,7 @@ def plot(ys: np.array, xs: Optional[np.array] = None, **kwargs) -> None:
                 options.y_min = options.y_min - step
                 options.y_max = options.y_max + step
             elif key_pressed == "r":
-                # Reset view
-                options.x_min = xs.min()
-                options.x_max = xs.max()
-                options.y_min = ys.min()
-                options.y_max = ys.max()
+                options.reset_view()
             elif key_pressed in ["q", "\x1b"]:
                 # q and Escape will end interactive mode
                 continue_looping = False
